#
# spec file for package libspnav
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2009,2011 Herbert Graeber
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libspnav
Version:        1.1
Release:        1.4
Summary:        Library for accessing 3D connexion devices
License:        BSD-3-Clause
Group:          Hardware/Other
URL:            https://sourceforge.net/projects/spacenav/
Source0:        https://github.com/FreeSpacenav/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)

%description
The libspnav library is provided as a replacement of the magellan library.
It provides a cleaner, and more orthogonal interface. libspnav supports
both the original X11 protocol for communicating with the driver, and the
new alternative non-X protocol. Programs that choose to use the X11
protocol, are automatically compatible with either the free spacenavd
driver or the official 3dxserv, as if they were using the magellan SDK.

Also, libspnav provides a magellan API wrapper on top of the new API. So,
any applications that were using the magellan library, can switch to
libspnav without any changes. And programmers that are familliar with the
magellan API can continue using it with a free library without the
restrictions of the official SDK.

%package -n libspnav0
Summary:        Library for accessing 3D connexion devices
Group:          Hardware/Other
Suggests:       spacenavd

%description -n libspnav0
The libspnav library is provided as a replacement of the magellan library.
It provides a cleaner, and more orthogonal interface. libspnav supports
both the original X11 protocol for communicating with the driver, and the
new alternative non-X protocol. Programs that choose to use the X11
protocol, are automatically compatible with either the free spacenavd
driver or the official 3dxserv, as if they were using the magellan SDK.

Also, libspnav provides a magellan API wrapper on top of the new API. So,
any applications that were using the magellan library, can switch to
libspnav without any changes. And programmers that are familliar with the
magellan API can continue using it with a free library without the
restrictions of the official SDK.

%package devel
Summary:        Include files for libspnav
Group:          Development/Libraries/C and C++
Requires:       libspnav0 = %{version}-%{release}

%description devel
The libspnav library is provided as a replacement of the magellan library.
It provides a cleaner, and more orthogonal interface. libspnav supports
both the original X11 protocol for communicating with the driver, and the
new alternative non-X protocol. Programs that choose to use the X11
protocol, are automatically compatible with either the free spacenavd
driver or the official 3dxserv, as if they were using the magellan SDK.

Also, libspnav provides a magellan API wrapper on top of the new API. So,
any applications that were using the magellan library, can switch to
libspnav without any changes. And programmers that are familliar with the
magellan API can continue using it with a free library without the
restrictions of the official SDK.

%prep
%autosetup -p1

# Set libdir properly
sed -i 's#libdir=lib#libdir=%{_lib}#' configure

%build
%configure
sed -i "s/CFLAGS =/CFLAGS +=/g" Makefile
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/libspnav.a

# the pkgconfig file shall be in %%_libdir/pkgconfig
mkdir -p %{buildroot}%{_libdir}/pkgconfig
mv %{buildroot}%{_datadir}/pkgconfig/spnav.pc %{buildroot}%{_libdir}/pkgconfig/

%post -n libspnav0 -p /sbin/ldconfig
%postun -n libspnav0 -p /sbin/ldconfig

%files -n libspnav0
%license LICENSE
%doc README.md examples
%{_libdir}/libspnav.so.*

%files devel
%{_includedir}/*.h
%{_libdir}/libspnav.so
%{_libdir}/pkgconfig/spnav.pc

%changelog
* Fri Dec 23 2022 Herbert Graeber <herbert@graeber-clan.de>
- Update to 1.1:
  * Fixed non-x11 build which was broken in v1.0.
  * Fixed out-of-source build regression.
  * Fixed potential crash in spnav_send_str: made it accept null pointers and send empty strings.
* Tue Apr  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.0:
  * Added support for spacenav protocol v1.
  * Added new API entry points, for the new capabilities
    introduced with protocol v1, including device queries,
    configuration management, new events, device identifier
    enumeration, etc.
  * Added utility functions for processing spacenav motion inputs
    and computing transformation matrices for object or view
    manipulation.
  * Added pkg-config file.
  * Added new example program, showing how to use 6dof input to
    control the view for flying in a 3D scene. This complements
    the cube example which shows how to manipulate 3D objects.
    Ported both examples to use the new helper functions.
  * Added API documentation under doc/manual.md
- Drop obsolete patch:
  * libspnav-0.2.3-lib_links.patch
* Tue Aug 28 2018 Herbert Graeber <herbert@graeber-clan.de> 0.2.3
- The project moved its official repository to github
- Add separate LICENSE file (formerly only available as part of the
  README file
* Sat Feb 14 2015 p.drouand@gmail.com
- Update to version 0.2.3
  * fixed invalid quaternion bug in cube example, when receiving
    zero-angle rotations.
  * fixed memory leak in spnav_remove_events.
  * makefile improvements (MacOS X build, DESTDIR, shared library
    symlinks, create missing install paths).
  * fixed bug when closing and reopening the connection to spacenavd.
- Add libspnav-0.2.3-lib_links.patch; fix libraries link against
  $BUILDROOT
* Wed Oct  1 2014 crrodriguez@opensuse.org
- Only use pkgconfig(x11) not xorg-x11-devel
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Tue Aug  9 2011 herbert@graeber-clan.de
- Corrected license to BSD
* Wed Aug  3 2011 toddrme2178@gmail.com
- Add a Url tag.
* Mon Jan 24 2011 herbert@graeber-clan.de
- update to version 0.2.2
- use separate changes file
* Sun Mar 22 2009 herbert@graeber-clan.de
- Initial package
